@@ -12,27 +12,32 @@ use {
     std::{
         collections::{hash_map::Entry, HashMap, HashSet},
         ops::Index,
-        sync::{atomic::AtomicBool, Arc},
+        sync::Arc,
         time::Instant,
     },
 };
 
-pub const MAX_ROOT_DISTANCE_FOR_VOTE_ONLY: Slot = 400;
-
-struct SetRootTimings {
+#[derive(Debug, Default, Copy, Clone)]
+struct SetRootMetrics {
+    timings: SetRootTimings,
     total_parent_banks: i64,
+    tx_count: i64,
+    dropped_banks_len: i64,
+    accounts_data_len: i64,
+}
+
+#[derive(Debug, Default, Copy, Clone)]
+struct SetRootTimings {
     total_squash_cache_ms: i64,
     total_squash_accounts_ms: i64,
     total_squash_accounts_index_ms: i64,
     total_squash_accounts_cache_ms: i64,
     total_squash_accounts_store_ms: i64,
     total_snapshot_ms: i64,
-    tx_count: i64,
     prune_non_rooted_ms: i64,
     drop_parent_banks_ms: i64,
     prune_slots_ms: i64,
     prune_remove_ms: i64,
-    dropped_banks_len: i64,
 }
 
 pub struct BankForks {
@@ -43,7 +48,6 @@ pub struct BankForks {
 
     pub accounts_hash_interval_slots: Slot,
     last_accounts_hash_slot: Slot,
-    in_vote_only_mode: Arc<AtomicBool>,
 }
 
 impl Index<u64> for BankForks {
@@ -59,20 +63,8 @@ impl BankForks {
         Self::new_from_banks(&[Arc::new(bank)], root)
     }
 
-    pub fn banks(&self) -> HashMap<Slot, Arc<Bank>> {
-        self.banks.clone()
-    }
-
-    pub fn get_vote_only_mode_signal(&self) -> Arc<AtomicBool> {
-        self.in_vote_only_mode.clone()
-    }
-
-    pub fn len(&self) -> usize {
-        self.banks.len()
-    }
-
-    pub fn is_empty(&self) -> bool {
-        self.banks.is_empty()
+    pub fn banks(&self) -> &HashMap<Slot, Arc<Bank>> {
+        &self.banks
     }
 
     /// Create a map of bank slot id to the set of ancestors for the bank slot.
@@ -88,8 +80,8 @@ impl BankForks {
     }
 
     /// Create a map of bank slot id to the set of all of its descendants
-    pub fn descendants(&self) -> HashMap<Slot, HashSet<Slot>> {
-        self.descendants.clone()
+    pub fn descendants(&self) -> &HashMap<Slot, HashSet<Slot>> {
+        &self.descendants
     }
 
     pub fn frozen_banks(&self) -> HashMap<Slot, Arc<Bank>> {
@@ -108,16 +100,16 @@ impl BankForks {
             .collect()
     }
 
-    pub fn get(&self, bank_slot: Slot) -> Option<Arc<Bank>> {
-        self.banks.get(&bank_slot).cloned()
+    pub fn get(&self, bank_slot: Slot) -> Option<&Arc<Bank>> {
+        self.banks.get(&bank_slot)
     }
 
     pub fn get_with_checked_hash(
         &self,
         (bank_slot, expected_hash): (Slot, Hash),
-    ) -> Option<Arc<Bank>> {
-        let maybe_bank = self.get(bank_slot);
-        if let Some(bank) = &maybe_bank {
+    ) -> Option<&Arc<Bank>> {
+        let maybe_bank = self.banks.get(&bank_slot);
+        if let Some(bank) = maybe_bank {
             assert_eq!(bank.hash(), expected_hash);
         }
         maybe_bank
@@ -160,7 +152,6 @@ impl BankForks {
             snapshot_config: None,
             accounts_hash_interval_slots: std::u64::MAX,
             last_accounts_hash_slot: root,
-            in_vote_only_mode: Arc::new(AtomicBool::new(false)),
         }
     }
 
@@ -211,7 +202,7 @@ impl BankForks {
         root: Slot,
         accounts_background_request_sender: &AbsRequestSender,
         highest_confirmed_root: Option<Slot>,
-    ) -> (Vec<Arc<Bank>>, SetRootTimings) {
+    ) -> (Vec<Arc<Bank>>, SetRootMetrics) {
         let old_epoch = self.root_bank().epoch();
         self.root = root;
         let root_bank = self
@@ -301,6 +292,7 @@ impl BankForks {
             total_squash_cache_ms += squash_timing.squash_cache_ms as i64;
         }
         let new_tx_count = root_bank.transaction_count();
+        let accounts_data_len = root_bank.load_accounts_data_len() as i64;
         let mut prune_time = Measure::start("set_root::prune");
         let (removed_banks, prune_slots_ms, prune_remove_ms) =
             self.prune_non_rooted(root, highest_confirmed_root);
@@ -313,20 +305,23 @@ impl BankForks {
 
         (
             removed_banks,
-            SetRootTimings {
+            SetRootMetrics {
+                timings: SetRootTimings {
+                    total_squash_cache_ms,
+                    total_squash_accounts_ms,
+                    total_squash_accounts_index_ms,
+                    total_squash_accounts_cache_ms,
+                    total_squash_accounts_store_ms,
+                    total_snapshot_ms,
+                    prune_non_rooted_ms: prune_time.as_ms() as i64,
+                    drop_parent_banks_ms: drop_parent_banks_time.as_ms() as i64,
+                    prune_slots_ms: prune_slots_ms as i64,
+                    prune_remove_ms: prune_remove_ms as i64,
+                },
                 total_parent_banks: total_parent_banks as i64,
-                total_squash_cache_ms,
-                total_squash_accounts_ms,
-                total_squash_accounts_index_ms,
-                total_squash_accounts_cache_ms,
-                total_squash_accounts_store_ms,
-                total_snapshot_ms,
                 tx_count: (new_tx_count - root_tx_count) as i64,
-                prune_non_rooted_ms: prune_time.as_ms() as i64,
-                drop_parent_banks_ms: drop_parent_banks_time.as_ms() as i64,
-                prune_slots_ms: prune_slots_ms as i64,
-                prune_remove_ms: prune_remove_ms as i64,
                 dropped_banks_len: dropped_banks_len as i64,
+                accounts_data_len,
             },
         )
     }
@@ -359,44 +354,57 @@ impl BankForks {
             ("total_banks", self.banks.len(), i64),
             (
                 "total_squash_cache_ms",
-                set_root_metrics.total_squash_cache_ms,
+                set_root_metrics.timings.total_squash_cache_ms,
                 i64
             ),
             (
                 "total_squash_accounts_ms",
-                set_root_metrics.total_squash_accounts_ms,
+                set_root_metrics.timings.total_squash_accounts_ms,
                 i64
             ),
             (
                 "total_squash_accounts_index_ms",
-                set_root_metrics.total_squash_accounts_index_ms,
+                set_root_metrics.timings.total_squash_accounts_index_ms,
                 i64
             ),
             (
                 "total_squash_accounts_cache_ms",
-                set_root_metrics.total_squash_accounts_cache_ms,
+                set_root_metrics.timings.total_squash_accounts_cache_ms,
                 i64
             ),
             (
                 "total_squash_accounts_store_ms",
-                set_root_metrics.total_squash_accounts_store_ms,
+                set_root_metrics.timings.total_squash_accounts_store_ms,
+                i64
+            ),
+            (
+                "total_snapshot_ms",
+                set_root_metrics.timings.total_snapshot_ms,
                 i64
             ),
-            ("total_snapshot_ms", set_root_metrics.total_snapshot_ms, i64),
             ("tx_count", set_root_metrics.tx_count, i64),
             (
                 "prune_non_rooted_ms",
-                set_root_metrics.prune_non_rooted_ms,
+                set_root_metrics.timings.prune_non_rooted_ms,
                 i64
             ),
             (
                 "drop_parent_banks_ms",
-                set_root_metrics.drop_parent_banks_ms,
+                set_root_metrics.timings.drop_parent_banks_ms,
+                i64
+            ),
+            (
+                "prune_slots_ms",
+                set_root_metrics.timings.prune_slots_ms,
+                i64
+            ),
+            (
+                "prune_remove_ms",
+                set_root_metrics.timings.prune_remove_ms,
                 i64
             ),
-            ("prune_slots_ms", set_root_metrics.prune_slots_ms, i64),
-            ("prune_remove_ms", set_root_metrics.prune_remove_ms, i64),
             ("dropped_banks_len", set_root_metrics.dropped_banks_len, i64),
+            ("accounts_data_len", set_root_metrics.accounts_data_len, i64),
         );
         removed_banks
     }
@@ -566,7 +574,7 @@ mod tests {
         let bank = Bank::new_from_parent(&bank0, &Pubkey::default(), 2);
         bank_forks.insert(bank);
         let descendants = bank_forks.descendants();
-        let children: HashSet<u64> = [1u64, 2u64].to_vec().into_iter().collect();
+        let children: HashSet<u64> = [1u64, 2u64].iter().copied().collect();
         assert_eq!(children, *descendants.get(&0).unwrap());
         assert!(descendants[&1].is_empty());
         assert!(descendants[&2].is_empty());
@@ -700,7 +708,7 @@ mod tests {
             ])
         );
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![
                 (0, vec![1, 2, 3, 4]),
                 (1, vec![2]),
@@ -717,7 +725,7 @@ mod tests {
         banks[2].squash();
         assert_eq!(bank_forks.ancestors(), make_hash_map(vec![(2, vec![]),]));
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![(0, vec![2]), (1, vec![2]), (2, vec![]),])
         );
         banks.push(bank_forks.insert(Bank::new_from_parent(&banks[2], &Pubkey::default(), 5)));
@@ -727,7 +735,7 @@ mod tests {
             make_hash_map(vec![(2, vec![]), (5, vec![2]), (6, vec![2, 5])])
         );
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![
                 (0, vec![2]),
                 (1, vec![2]),
@@ -759,7 +767,7 @@ mod tests {
             ])
         );
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![
                 (0, vec![1, 2, 3, 4]),
                 (1, vec![2]),
@@ -779,7 +787,7 @@ mod tests {
             make_hash_map(vec![(1, vec![]), (2, vec![]),])
         );
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![(0, vec![1, 2]), (1, vec![2]), (2, vec![]),])
         );
         banks.push(bank_forks.insert(Bank::new_from_parent(&banks[2], &Pubkey::default(), 5)));
@@ -794,7 +802,7 @@ mod tests {
             ])
         );
         assert_eq!(
-            bank_forks.descendants(),
+            *bank_forks.descendants(),
             make_hash_map(vec![
                 (0, vec![1, 2]),
                 (1, vec![2]),
